==> pegasus-merchandise-api-2.1.1-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpProdDynmDetailsHistoryCond.java <==
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.pegasus.util.cond.BaseQueryCond;

import java.util.Date;

/**
 * Created by gensheng.ye on 2019/1/2.
 */
public class OpProdDynmDetailsHistoryCond extends BaseQueryCond {
    private Long id;
    private String prodCode;
    private Integer prodId;
    private Integer dynmcontId;
    private Integer dynmType;
    private Date createTimeStart;
    private Date createTimeEnd;
    private String status;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public Integer getProdId() {
        return prodId;
    }

    public void setProdId(Integer prodId) {
        this.prodId = prodId;
    }

    public Integer getDynmcontId() {
        return dynmcontId;
    }

    public void setDynmcontId(Integer dynmcontId) {
        this.dynmcontId = dynmcontId;
    }

    public Integer getDynmType() {
        return dynmType;
    }

    public void setDynmType(Integer dynmType) {
        this.dynmType = dynmType;
    }

    public Date getCreateTimeStart() {
        return createTimeStart;
    }

    public void setCreateTimeStart(Date createTimeStart) {
        this.createTimeStart = createTimeStart;
    }

    public Date getCreateTimeEnd() {
        return createTimeEnd;
    }

    public void setCreateTimeEnd(Date createTimeEnd) {
        this.createTimeEnd = createTimeEnd;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }



}

==> pegasus-merchandise-api-3.9.91-sources.jar: com/thebeastshop/pegasus/merchandise/cond/OpProdDynmDetailsHistoryCond.java <==
package com.thebeastshop.pegasus.merchandise.cond;

import com.thebeastshop.common.BaseQueryCond;

import java.util.Date;

/**
 * Created by gensheng.ye on 2019/1/2.
 */
public class OpProdDynmDetailsHistoryCond extends BaseQueryCond {
    private Long id;
    private String prodCode;
    private Integer prodId;
    private Integer dynmcontId;
    private Integer dynmType;
    private Date createTimeStart;
    private Date createTimeEnd;
    private String status;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getProdCode() {
        return prodCode;
    }

    public void setProdCode(String prodCode) {
        this.prodCode = prodCode;
    }

    public Integer getProdId() {
        return prodId;
    }

    public void setProdId(Integer prodId) {
        this.prodId = prodId;
    }

    public Integer getDynmcontId() {
        return dynmcontId;
    }

    public void setDynmcontId(Integer dynmcontId) {
        this.dynmcontId = dynmcontId;
    }

    public Integer getDynmType() {
        return dynmType;
    }

    public void setDynmType(Integer dynmType) {
        this.dynmType = dynmType;
    }

    public Date getCreateTimeStart() {
        return createTimeStart;
    }

    public void setCreateTimeStart(Date createTimeStart) {
        this.createTimeStart = createTimeStart;
    }

    public Date getCreateTimeEnd() {
        return createTimeEnd;
    }

    public void setCreateTimeEnd(Date createTimeEnd) {
        this.createTimeEnd = createTimeEnd;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }



}
